==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ConsistentHashFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ConsistentHashFluentImpl<A extends ConsistentHashFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ConsistentHashFluent<A>{

    private ConsistentHashLBBuilder consistentHash;

    public ConsistentHashFluentImpl(){
    }
    public ConsistentHashFluentImpl(ConsistentHash instance){
            this.withConsistentHash(instance.getConsistentHash()); 
    }

    
/**
 * This method has been deprecated, please use method buildConsistentHash instead.
 * @return The buildable object.
 */
@Deprecated public ConsistentHashLB getConsistentHash(){
            return this.consistentHash!=null?this.consistentHash.build():null;
    }

    public ConsistentHashLB buildConsistentHash(){
            return this.consistentHash!=null?this.consistentHash.build():null;
    }

    public A withConsistentHash(ConsistentHashLB consistentHash){
            _visitables.remove(this.consistentHash);
            if (consistentHash!=null){ this.consistentHash= new ConsistentHashLBBuilder(consistentHash); _visitables.add(this.consistentHash);} return (A) this;
    }

    public Boolean hasConsistentHash(){
            return this.consistentHash != null;
    }

    public ConsistentHashFluent.ConsistentHashNested<A> withNewConsistentHash(){
            return new ConsistentHashNestedImpl();
    }

    public ConsistentHashFluent.ConsistentHashNested<A> withNewConsistentHashLike(ConsistentHashLB item){
            return new ConsistentHashNestedImpl(item);
    }

    public ConsistentHashFluent.ConsistentHashNested<A> editConsistentHash(){
            return withNewConsistentHashLike(getConsistentHash());
    }

    public ConsistentHashFluent.ConsistentHashNested<A> editOrNewConsistentHash(){
            return withNewConsistentHashLike(getConsistentHash() != null ? getConsistentHash(): new ConsistentHashLBBuilder().build());
    }

    public ConsistentHashFluent.ConsistentHashNested<A> editOrNewConsistentHashLike(ConsistentHashLB item){
            return withNewConsistentHashLike(getConsistentHash() != null ? getConsistentHash(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ConsistentHashFluentImpl that = (ConsistentHashFluentImpl) o;
            if (consistentHash != null ? !consistentHash.equals(that.consistentHash) :that.consistentHash != null) return false;
            return true;
    }


    public class ConsistentHashNestedImpl<N> extends ConsistentHashLBFluentImpl<ConsistentHashFluent.ConsistentHashNested<N>> implements ConsistentHashFluent.ConsistentHashNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ConsistentHashLBBuilder builder;
    
            ConsistentHashNestedImpl(ConsistentHashLB item){
                    this.builder = new ConsistentHashLBBuilder(this, item);
            }
            ConsistentHashNestedImpl(){
                    this.builder = new ConsistentHashLBBuilder(this);
            }
    
    public N and(){
            return (N) ConsistentHashFluentImpl.this.withConsistentHash(builder.build());
    }
    public N endConsistentHash(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ConsistentHashFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ConsistentHashFluentImpl<A extends ConsistentHashFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ConsistentHashFluent<A>{

    private ConsistentHashLBBuilder consistentHash;

    public ConsistentHashFluentImpl(){
    }
    public ConsistentHashFluentImpl(ConsistentHash instance){
            this.withConsistentHash(instance.getConsistentHash()); 
    }

    
/**
 * This method has been deprecated, please use method buildConsistentHash instead.
 * @return The buildable object.
 */
@Deprecated public ConsistentHashLB getConsistentHash(){
            return this.consistentHash!=null?this.consistentHash.build():null;
    }

    public ConsistentHashLB buildConsistentHash(){
            return this.consistentHash!=null?this.consistentHash.build():null;
    }

    public A withConsistentHash(ConsistentHashLB consistentHash){
            _visitables.get("consistentHash").remove(this.consistentHash);
            if (consistentHash!=null){ this.consistentHash= new ConsistentHashLBBuilder(consistentHash); _visitables.get("consistentHash").add(this.consistentHash);} return (A) this;
    }

    public Boolean hasConsistentHash(){
            return this.consistentHash != null;
    }

    public ConsistentHashFluent.ConsistentHashNested<A> withNewConsistentHash(){
            return new ConsistentHashNestedImpl();
    }

    public ConsistentHashFluent.ConsistentHashNested<A> withNewConsistentHashLike(ConsistentHashLB item){
            return new ConsistentHashNestedImpl(item);
    }

    public ConsistentHashFluent.ConsistentHashNested<A> editConsistentHash(){
            return withNewConsistentHashLike(getConsistentHash());
    }

    public ConsistentHashFluent.ConsistentHashNested<A> editOrNewConsistentHash(){
            return withNewConsistentHashLike(getConsistentHash() != null ? getConsistentHash(): new ConsistentHashLBBuilder().build());
    }

    public ConsistentHashFluent.ConsistentHashNested<A> editOrNewConsistentHashLike(ConsistentHashLB item){
            return withNewConsistentHashLike(getConsistentHash() != null ? getConsistentHash(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ConsistentHashFluentImpl that = (ConsistentHashFluentImpl) o;
            if (consistentHash != null ? !consistentHash.equals(that.consistentHash) :that.consistentHash != null) return false;
            return true;
    }


    public class ConsistentHashNestedImpl<N> extends ConsistentHashLBFluentImpl<ConsistentHashFluent.ConsistentHashNested<N>> implements ConsistentHashFluent.ConsistentHashNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ConsistentHashLBBuilder builder;
    
            ConsistentHashNestedImpl(ConsistentHashLB item){
                    this.builder = new ConsistentHashLBBuilder(this, item);
            }
            ConsistentHashNestedImpl(){
                    this.builder = new ConsistentHashLBBuilder(this);
            }
    
    public N and(){
            return (N) ConsistentHashFluentImpl.this.withConsistentHash(builder.build());
    }
    public N endConsistentHash(){
            return and();
    }

}


}
